---
permalink: /functions
---

# Funktionen

Der KMUHelper ist ein Tool für Schweizer KMU, mit welchem die Buchhaltung erledigt werden kann.

Hier eine kleine Liste mit den wichtigsten Funktionen:

-   Erfassen von Bestellungen
-   Druck von QR-Rechnungen
-   Lagerverwaltung
-   Kundenmanagement
-   Eigene (Web-)App für unterwegs
-   ... und noch viel mehr!

## Wichtige Infos

Bitte beachten SIe, dass der KMUHelper (zurzeit) nur für Bestellungen innerhalb Schweiz/Liechtenstein ausgelegt ist.

Ich übernehme KEINE GARANTIE bei fehlerhafter Programmierung meinerseits, bin aber gerne bereit, Ihr Problem so schnell wie möglich zu lösen. (Eröffnen Sie dazu ein [Issue](<{{ site.github.repository_url }}/issues>) oder [kontaktieren Sie mich](https://rafaelurben.github.io/diverses/rafaelurben/#kontakt).)

## Zurück

[Zurück zur Startseite](./)
